<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>UPS.com | Global Shipping & Logistics Services</title>
    <link rel="shortcut icon" href="logo.svg" type="image/x-icon">
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
        }

        :root {
            --ups-brown: #351c15;
            --ups-yellow: #ffbe0b;
            --ups-blue: #2d6ba1;
        }

        /* Header Styles */
        .top-bar {
            display: flex;
            justify-content: space-between;
            padding: 0.5rem 2rem;
            background: #fff;
            align-items: center;
        }

        .location-link {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            text-decoration: none;
            color: #000;
        }

        .right-nav {
            display: flex;
            gap: 1rem;
            align-items: center;
        }

        .main-nav {
            display: flex;
            align-items: center;
            padding: 0.5rem 2rem;
            background: #fff;
            justify-content: space-between;
        }

        .logo {
            width: 50px;
            height: auto;
        }

        .nav-links {
            display: flex;
            gap: 2rem;
        }

        .nav-links a {
            text-decoration: none;
            color: #000;
        }

        .login-btn {
            background: var(--ups-yellow);
            border: none;
            padding: 0.5rem 1rem;
            border-radius: 4px;
            cursor: pointer;
        }

        /* Hero Section */
        .hero {
            background: var(--ups-brown);
            padding: 2rem;
            position: relative;
            padding-bottom: 6rem;
        }

        .hero::after {
            content: '';
            position: absolute;
            bottom: -1px;
            left: 0;
            width: 100%;
            height: 60px;
            background: #fff;
            border-radius: 100% 100% 0 0;
        }

        .tracking-nav {
            display: flex;
            gap: 2rem;
            margin-bottom: 2rem;
        }

        .tracking-nav a {
            color: #fff;
            text-decoration: none;
            font-weight: 500;
        }

        .tracking-input {
            display: flex;
            gap: 1rem;
            max-width: 600px;
        }

        .tracking-input input {
            flex: 1;
            padding: 0.75rem;
            border: none;
            border-radius: 4px;
        }

        .track-btn {
            background: var(--ups-yellow);
            border: none;
            padding: 0.75rem 1.5rem;
            border-radius: 4px;
            cursor: pointer;
        }

        /* Schedule Pickup Section */
        .schedule-pickup {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 2rem;
            padding: 4rem 2rem;
            background: #f5f5f5;
        }

        .pickup-image {
            width: 100%;
            height: auto;
            border-radius: 8px;
        }

        .pickup-content h2 {
            font-size: 2rem;
            margin-bottom: 1rem;
        }

        .pickup-btn {
            display: inline-block;
            background: var(--ups-yellow);
            padding: 0.75rem 1.5rem;
            border-radius: 4px;
            text-decoration: none;
            color: #000;
            margin-top: 1rem;
        }

        /* Packing Section */
        .packing-section {
            background: var(--ups-blue);
            color: #fff;
            padding: 2rem;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        /* Services Section */
        .services {
            padding: 4rem 2rem;
            text-align: center;
        }

        .services h2 {
            font-size: 2rem;
            margin-bottom: 0.5rem;
        }

        .services-subtitle {
            color: #666;
            margin-bottom: 3rem;
        }

        .service-cards {
            display: grid;
            grid-template-columns: repeat(2, 1fr);
            gap: 2rem;
            max-width: 1200px;
            margin: 0 auto;
        }

        .service-card {
            text-align: left;
            border: 1px solid #ddd;
            padding: 1rem;
            border-radius: 8px;
        }

        .service-card img {
            width: 100%;
            height: 200px;
            object-fit: cover;
            border-radius: 4px;
            margin-bottom: 1rem;
        }

        /* Quick Links Section */
        .quick-links {
            padding: 4rem 2rem;
            background: #f5f5f5;
        }

        .quick-links h2 {
            text-align: center;
            margin-bottom: 2rem;
        }

        .links-grid {
            display: grid;
            grid-template-columns: repeat(3, 1fr);
            gap: 2rem;
            max-width: 1200px;
            margin: 0 auto;
        }

        .links-grid a {
            color: var(--ups-blue);
            text-decoration: none;
        }

        /* Footer */
        footer {
            background: var(--ups-brown);
            color: #fff;
            padding: 4rem 2rem;
        }

        .footer-grid {
            display: grid;
            grid-template-columns: repeat(4, 1fr);
            gap: 2rem;
            max-width: 1200px;
            margin: 0 auto;
        }

        .footer-grid h3 {
            margin-bottom: 1rem;
        }

        .footer-grid a {
            color: #fff;
            text-decoration: none;
            display: block;
            margin-bottom: 0.5rem;
            opacity: 0.8;
        }

        @media (max-width: 768px) {
            .service-cards,
            .links-grid,
            .footer-grid {
                grid-template-columns: 1fr;
            }

            .schedule-pickup {
                grid-template-columns: 1fr;
            }
        }
    </style>
</head>
<body>
    <header>
        <div class="top-bar">
            <a href="#" class="location-link">
                📍 Find UPS Closest Location
            </a>
            <div class="right-nav">
                <a href="#">Service Alerts</a>
                <select>
                    <option>United States - English</option>
                </select>
                <a href="#">Support</a>
            </div>
        </div>
        <nav class="main-nav">
            <img src="./logo.svg" alt="UPS Logo" class="logo">
            <div class="nav-links">
                <a href="#">Shipping</a>
                <a href="#">Tracking</a>
                <a href="#">Products & Services</a>
                <a href="#">The UPS Store</a>
            </div>
            <button class="login-btn">Log In ›</button>
        </nav>
    </header>

    <section class="hero">
        <nav class="tracking-nav">
            <a href="#">Track</a>
            <a href="#">Quote</a>
            <a href="#">Ship</a>
            <a href="#">Billing</a>
        </nav>
            <!-- <div class="tracking-input"> -->
                <!-- <input type="text" placeholder="Tracking Number or InfoNotice®">
                <button class="track-btn" >Track</button> -->
            <form action="tracking_details.php" method="POST" class="tracking-input">
                <input type="text" name="tracking_number"  placeholder="Tracking Number or InfoNotice®" required>
                <button type="submit" class="track-btn">Track</button>
            </form>               
            <!-- </div> -->
    </section>

    <section class="schedule-pickup">
        <img src="./media_1183b394323caf0254f26c093eb934df7a4a8eb89.webp" alt="UPS Delivery" class="pickup-image">
        <div class="pickup-content">
            <h2>Schedule a Pickup</h2>
            <p>One-time or recurring, find an option that best fits your business.</p>
            <a href="#" class="pickup-btn">See Pickup Options ›</a>
        </div>
    </section>

    <section class="packing-section">
        <h2>Leave Packing to the Pros</h2>
        <a href="#" class="pickup-btn">Find a UPS Store ›</a>
    </section>

    <section class="services">
        <h2>World-Class Services You Can Count On</h2>
        <p class="services-subtitle">Customer first, people led, innovation driven.</p>
        <div class="service-cards">
            <div class="service-card">
                <img src="./default (1).webp" alt="Returns Service">
                <h3>UPS and Happy Returns Make Customer Returns Easy</h3>
                <p>Together, we're empowering businesses to offer easier returns by combining innovative tech expertise with the reach logistics.</p>
                <a href="#">Read More ›</a>
            </div>
            <div class="service-card">
                <img src="./default (2).webp" alt="Business Delivery">
                <h3>UPS Helps Businesses Deliver More Than Just Packages</h3>
                <p>See why entrepreneurs trust UPS for fast, reliable and innovative worldwide shipping solutions through real customer stories.</p>
                <a href="#">See the Testimonials ›</a>
            </div>
        </div>
    </section>

    <section class="quick-links">
        <h2>Quick Links</h2>
        <div class="links-grid">
            <a href="#">UPS My Choice® Login</a>
            <a href="#">UPS My Choice® for Business Login</a>
            <a href="#">Help and Support Center</a>
            <a href="#">Order Supplies</a>
            <a href="#">File a Claim</a>
            <a href="#">Book a Business Consultation ›</a>
        </div>
    </section>

    <footer>
        <div class="footer-grid">
            <div>
                <h3>This Site</h3>
                <a href="#">Tracking</a>
                <a href="#">Shipping</a>
                <a href="#">Support</a>
            </div>
            <div>
                <h3>UPS Sites</h3>
                <a href="#">About UPS</a>
                <a href="#">UPS Jobs</a>
                <a href="#">UPS Healthcare</a>
            </div>
            <div>
                <h3>UPS Companies</h3>
                <a href="#">Happy Returns</a>
                <a href="#">Roadie</a>
                <a href="#">Delivery Solutions</a>
            </div>
            <div>
                <h3>Connect with Us</h3>
                <a href="#">Facebook</a>
                <a href="#">Twitter</a>
                <a href="#">Instagram</a>
            </div>
        </div>
    </footer>


    <!-- <script>
        document.querySelector(".track-btn").addEventListener("click", function() {
    const trackingInput = document.querySelector(".tracking-input input");
    const trackingNumber = trackingInput.value.trim();

    if (trackingNumber === "") {
        alert("Please enter a tracking number.");
        return;
    }

    fetch("tracking_details.php", {
        method: "POST",
        headers: {
            "Content-Type": "application/x-www-form-urlencoded"
        },
        body: `tracking_number=${encodeURIComponent(trackingNumber)}`
    })
    .then(response => response.json())
    .then(data => {
        if (data.status === "success") {
            window.location.href = "tracking_details.php";
        } else {
            alert(data.message);
        }
    })
    .catch(error => console.error("Error:", error));
});

    </script> -->
</body>
</html>