<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Shipping Information Form</title>
    <link rel="shortcut icon" href="logo.svg" type="image/x-icon">
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
        }

        :root {
            --ups-brown: #351c15;
            --ups-yellow: #ffbe0b;
            --border-color: #ddd;
            --section-bg: #f8f8f8;
        }

        body {
            background-color: #f5f5f5;
            color: #333;
            line-height: 1.6;
        }

        .container {
            max-width: 1000px;
            margin: 40px auto;
            padding: 0 20px;
        }

        .form-header {
            text-align: center;
            margin-bottom: 40px;
        }

        .form-header h1 {
            color: var(--ups-brown);
            font-size: 32px;
            margin-bottom: 10px;
        }

        .form-section {
            background: white;
            border-radius: 10px;
            padding: 30px;
            margin-bottom: 20px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }

        .section-title {
            color: var(--ups-brown);
            font-size: 20px;
            margin-bottom: 20px;
            padding-bottom: 10px;
            border-bottom: 2px solid var(--ups-yellow);
        }

        .form-grid {
            display: grid;
            grid-template-columns: repeat(2, 1fr);
            gap: 20px;
        }

        .form-group {
            margin-bottom: 20px;
        }

        .form-group.full-width {
            grid-column: 1 / -1;
        }

        label {
            display: block;
            margin-bottom: 8px;
            font-weight: 500;
            color: #444;
        }

        input[type="text"],
        input[type="tel"],
        input[type="email"],
        input[type="number"],
        input[type="datetime-local"],
        select,
        textarea {
            width: 100%;
            padding: 12px;
            border: 1px solid var(--border-color);
            border-radius: 6px;
            font-size: 16px;
            transition: border-color 0.3s, box-shadow 0.3s;
        }

        input:focus,
        select:focus,
        textarea:focus {
            outline: none;
            border-color: var(--ups-yellow);
            box-shadow: 0 0 0 3px rgba(255, 190, 11, 0.2);
        }

        .generate-code {
            background: var(--ups-yellow);
            color: var(--ups-brown);
            border: none;
            padding: 15px 30px;
            border-radius: 6px;
            font-size: 18px;
            font-weight: 600;
            cursor: pointer;
            width: 100%;
            transition: background-color 0.3s;
        }

        .generate-code:hover {
            background-color: #ffa500;
        }

        .required {
            color: #dc2626;
            margin-left: 4px;
        }

        .optional {
            color: #666;
            font-size: 14px;
            margin-left: 4px;
        }

        @media (max-width: 768px) {
            .form-grid {
                grid-template-columns: 1fr;
            }

            .container {
                margin: 20px auto;
            }

            .form-section {
                padding: 20px;
            }
        }

        .notification-badge {
            background: var(--ups-brown);
            color: white;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 14px;
            margin-left: 8px;
        }

        .id-type-info {
            font-size: 14px;
            color: #666;
            margin-top: 4px;
        }

        .luggage-details {
            background: var(--section-bg);
            padding: 15px;
            border-radius: 6px;
            margin-top: 10px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="form-header">
            <h1>Shipping Information Form</h1>
            <p>Please fill in all required information for your shipment</p>
        </div>

        <form id="shippingForm" action="save_shipping.php" method="POST">
            <!-- Notification Section -->
            <div class="form-section">
                <h2 class="section-title">Notification Information</h2>
                <div class="form-grid">
                    <div class="form-group">
                        <label>Current Location <span class="required">*</span></label>
                        <input type="text" name="current_location" required>
                    </div>
                    <div class="form-group">
                        <label>Tracking Code <span class="required">*</span></label>
                        <input type="text" placeholder="Will be Saved as the Tracking ID" name="tracking_code" required>
                    </div>
                </div>
                <div class="form-group">
                    <button type="button" class="generate-code">Update Current Location </button>
                </div>
            </div>

            <!-- Location Section -->
            <div class="form-section">
                <h2 class="section-title">Location Details</h2>
                <div class="form-grid">
                    <div class="form-group">
                        <label>Country From <span class="required">*</span></label>
                        <input type="text" name="country_from">
                        <!-- <select required>
                            <option value="">Select Country</option>
                            <option value="US">United States</option>
                            <option value="UK">United Kingdom</option>
                            Add more countries
                        </select> -->
                    </div>
                    <div class="form-group">
                        <label>Country To <span class="required">*</span></label>
                        <input type="text" name="country_to">
                        <!-- <select required>
                            <option value="">Select Country</option>
                            <option value="US">United States</option>
                            <option value="UK">United Kingdom</option>
                            Add more countries
                        </select> -->
                    </div>
                </div>
            </div>

            <!-- Sender Information -->
<div class="form-section">
    <h2 class="section-title">Sender Information</h2>
    <div class="form-grid">
        <div class="form-group">
            <label>Sender Name <span class="required">*</span></label>
            <input type="text" name="sender_name" required>
        </div>
        <div class="form-group">
            <label>Sender Contact <span class="required">*</span></label>
            <input type="tel" name="sender_contact" required>
        </div>
        <div class="form-group full-width">
            <label>Sender Address <span class="required">*</span></label>
            <textarea rows="3" name="sender_address" required></textarea>
        </div>
        <div class="form-group">
            <label>Sender ID Type <span class="required">*</span></label>
            <input type="text" name="sender_id_type" required>
        </div>
        <div class="form-group">
            <label>ID Number <span class="required">*</span></label>
            <input type="text" name="sender_id_number" required>
        </div>
    </div>
</div>

<!-- Receiver Information -->
<div class="form-section">
    <h2 class="section-title">Receiver Information</h2>
    <div class="form-grid">
        <div class="form-group">
            <label>Receiver Name <span class="required">*</span></label>
            <input type="text" name="receiver_name" required>
        </div>
        <div class="form-group">
            <label>Receiver Contact <span class="required">*</span></label>
            <input type="tel" name="receiver_contact" required>
        </div>
        <div class="form-group full-width">
            <label>Receiver Address <span class="required">*</span></label>
            <textarea rows="3" name="receiver_address" required></textarea>
        </div>
        <div class="form-group">
            <label>ID Required for Collection</label>
            <select name="receiver_id_required">
                <option value="government">Government Issued ID</option>
                <option value="any">Any Valid ID</option>
                <option value="none">No ID Required</option>
            </select>
        </div>
    </div>
</div>

<!-- Shipment Details -->
<div class="form-section">
    <h2 class="section-title">Shipment Details</h2>
    <div class="form-grid">
        <div class="form-group">
            <label>Departure Airport <span class="required">*</span></label>
            <input type="text" name="departure_airport" required>
        </div>
        <div class="form-group">
            <label>Arrival Airport <span class="required">*</span></label>
            <input type="text" name="arrival_airport" required>
        </div>
        <div class="form-group">
            <label>Departure Date & Time <span class="required">*</span></label>
            <input type="datetime-local" name="departure_datetime" required>
        </div>
        <div class="form-group">
            <label>Arrival Date & Time <span class="required">*</span></label>
            <input type="datetime-local" name="arrival_datetime" required>
        </div>
        <div class="form-group">
            <label>Total Weight (kg) <span class="required">*</span></label>
            <input type="number" step="0.1" name="total_weight" required>
        </div>
        <div class="form-group">
            <label>Number of Packages <span class="required">*</span></label>
            <input type="number" name="number_of_packages" required>
        </div>
    </div>
</div>

<!-- Luggage Details -->
<div class="form-section">
    <h2 class="section-title">Luggage Details</h2>
    <div class="luggage-details">
        <div class="form-grid">
            <div class="form-group">
                <label>Luggage Type</label>
                <select name="luggage_type">
                    <option value="suitcase">Suitcase</option>
                    <option value="box">Box</option>
                    <option value="bag">Bag</option>
                    <option value="other">Other</option>
                </select>
            </div>
            <div class="form-group">
                <label>Special Handling Instructions <span class="optional">(optional)</span></label>
                <input type="text" name="special_instructions">
            </div>
            <div class="form-group full-width">
                <label>Additional Notes <span class="optional">(optional)</span></label>
                <textarea rows="3" name="additional_notes"></textarea>
            </div>
        </div>
    </div>
</div>

            <div class="form-group">
                <button type="submit" class="generate-code">Submit Shipping Information</button>
            </div>
        </form>
    </div>
</body>
</html>