<?php
// Database connection
$host = 'localhost';
$user = 'root'; // Change if needed
$pass = ''; // Change if needed
$dbname = 'shipping_db';
$conn = new mysqli($host, $user, $pass, $dbname);

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Initialize variables
$tracking_number = '';
$shipment = null;
$error_message = '';

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $tracking_number = trim($_POST['tracking_number']);

    if (!empty($tracking_number)) {
        $stmt = $conn->prepare("SELECT * FROM shipping_info WHERE tracking_code = ?");
        $stmt->bind_param("s", $tracking_number);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $shipment = $result->fetch_assoc();
        } else {
            $error_message = "Tracking number not found.";
        }
        
        $stmt->close();
    } else {
        $error_message = "Please enter a tracking number.";
    }
}
$conn->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tracking | UPS</title>
    <link rel="shortcut icon" href="logo.svg" type="image/x-icon">
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
        }

        :root {
            --ups-brown: #351c15;
            --ups-yellow: #ffbe0b;
        }

        /* Top Bar */
        .top-bar {
            background: #f5f5f5;
            padding: 8px 24px;
            display: flex;
            justify-content: space-between;
            align-items: center;
            font-size: 14px;
        }

        .location-finder {
            display: flex;
            align-items: center;
            gap: 8px;
            color: #333;
            text-decoration: none;
        }

        .top-right {
            display: flex;
            align-items: center;
            gap: 24px;
        }

        /* Main Header */
        .main-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 16px 24px;
            border-bottom: 1px solid #ddd;
        }

        .logo {
            width: 60px;
            height: auto;
        }

        .nav-links {
            display: flex;
            gap: 32px;
        }

        .nav-links a {
            text-decoration: none;
            color: #333;
        }

        .login-btn {
            background: var(--ups-yellow);
            border: none;
            padding: 8px 16px;
            border-radius: 4px;
            font-weight: 500;
            cursor: pointer;
        }

        /* Main Content */
        .main-content {
            display: grid;
            grid-template-columns: 1fr 300px;
            gap: 32px;
            max-width: 1200px;
            margin: 32px auto;
            padding: 0 24px;
        }

        .tracking-section {
            background: white;
            border-radius: 8px;
            padding: 24px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }

        .error-message {
            background: #fff5f5;
            border: 1px solid #ff4444;
            color: #dc2626;
            padding: 16px;
            border-radius: 4px;
            margin-bottom: 24px;
        }

        .error-message h3 {
            display: flex;
            align-items: center;
            gap: 8px;
            color: #dc2626;
            margin-bottom: 8px;
        }

        .tracking-form {
            margin-top: 24px;
        }

        .tracking-input {
            width: 100%;
            padding: 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            margin-bottom: 16px;
        }

        .track-btn {
            background: var(--ups-yellow);
            border: none;
            padding: 12px 24px;
            border-radius: 4px;
            font-weight: 500;
            cursor: pointer;
        }

        /* Sidebar */
        .sidebar {
            display: flex;
            flex-direction: column;
            gap: 24px;
        }

        .sidebar-card {
            background: white;
            border-radius: 8px;
            padding: 24px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }

        .sidebar-links {
            display: flex;
            flex-direction: column;
            gap: 12px;
        }

        .sidebar-links a {
            color: #0066cc;
            text-decoration: none;
        }

        /* Footer */
        footer {
            background: var(--ups-brown);
            color: white;
            padding: 48px 24px;
            margin-top: 48px;
        }

        .footer-content {
            max-width: 1200px;
            margin: 0 auto;
            display: grid;
            grid-template-columns: repeat(4, 1fr);
            gap: 32px;
        }

        .footer-column h3 {
            margin-bottom: 16px;
            font-size: 16px;
        }

        .footer-links {
            display: flex;
            flex-direction: column;
            gap: 12px;
        }

        .footer-links a {
            color: #fff;
            text-decoration: none;
            opacity: 0.8;
        }

        .footer-bottom {
            max-width: 1200px;
            margin: 48px auto 0;
            padding-top: 24px;
            border-top: 1px solid rgba(255,255,255,0.1);
            font-size: 14px;
            opacity: 0.8;
        }

        @media (max-width: 768px) {
            .main-content {
                grid-template-columns: 1fr;
            }

            .footer-content {
                grid-template-columns: repeat(2, 1fr);
            }

            .nav-links {
                display: none;
            }
        }

            .shipment-summary {
            background: white;
            border-radius: 8px;
            padding: 24px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }

        .summary-title {
            color: var(--ups-brown);
            font-size: 24px;
            margin-bottom: 20px;
            padding-bottom: 10px;
            border-bottom: 2px solid var(--ups-yellow);
        }

        .summary-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
            gap: 20px;
        }

        .summary-item {
            background: var(--section-bg);
            padding: 15px;
            border-radius: 6px;
        }

        .summary-item h3 {
            color: var(--ups-brown);
            font-size: 16px;
            margin-bottom: 8px;
        }

        .summary-item p {
            margin-bottom: 4px;
        }

        .status-badge {
            display: inline-block;
            background: var(--ups-yellow);
            color: var(--ups-brown);
            padding: 4px 8px;
            border-radius: 4px;
            font-weight: bold;
        }

        .action-buttons {
            margin-top: 24px;
            display: flex;
            gap: 12px;
        }

        .ups-btn {
            padding: 12px 20px;
            border: none;
            border-radius: 4px;
            font-weight: 600;
            cursor: pointer;
            transition: background-color 0.3s;
        }

        .ups-btn.primary {
            background: var(--ups-yellow);
            color: var(--ups-brown);
        }

        .ups-btn.primary:hover {
            background: #ffa500;
        }

        .ups-btn.secondary {
            background: var(--ups-brown);
            color: white;
        }

        .ups-btn.secondary:hover {
            background: #4a2b22;
        }

        @media (max-width: 768px) {
            .summary-grid {
                grid-template-columns: 1fr;
            }

            .action-buttons {
                flex-direction: column;
            }
        }
        
    </style>
</head>
<body>
    <div class="top-bar">
        <a href="#" class="location-finder">
            📍 Find Closest UPS Location
        </a>
        <div class="top-right">
            <a href="#">Service Alerts</a>
            <select>
                <option>United States - English</option>
            </select>
            <a href="#">Support</a>
        </div>
    </div>

    <header class="main-header">
        <img src="logo.svg" alt="UPS Logo" class="logo">
        <nav class="nav-links">
            <a href="#">Shipping</a>
            <a href="#">Tracking</a>
            <a href="#">Products & Services</a>
            <a href="#">The UPS Store</a>
        </nav>
        <button class="login-btn">Log In →</button>
    </header>
    <?php if ($error_message): ?>
        <div class="error-message">
            <p><?php echo $error_message; ?></p>
        </div>
    <?php endif; ?>

    <?php if ($shipment): ?>

    <main class="main-content">
        <div class="tracking-section">
        <div class="shipment-summary">
                <h2 class="summary-title">Shipment Summary</h2>
                <div class="summary-grid">
                    <div class="summary-item">
                        <h3>Tracking Number</h3>
                        <p><?php echo htmlspecialchars($shipment['tracking_code']); ?></p>
                    </div>
                    <div class="summary-item">
                        <h3>Status</h3>
                        <p class="status-badge"> <?php echo htmlspecialchars($shipment['status']); ?></p>
                    </div>
                    <div class="summary-item">
                        <h3>Sender</h3>
                        <p><?php echo htmlspecialchars($shipment['sender_name']); ?></p>
                        <p><?php echo htmlspecialchars($shipment['sender_address']); ?></p>
                    </div>
                    <div class="summary-item">
                        <h3>Receiver</h3>
                        <p><?php echo htmlspecialchars($shipment['receiver_name']); ?></p>
                        <p><?php echo htmlspecialchars($shipment['receiver_address']); ?></p>
                    </div>
                    <div class="summary-item">
                        <h3>Shipment Details</h3>
                        <p>Weight: <?php echo htmlspecialchars($shipment['total_weight']); ?> kg</p>
                        <p>Packages: <?php echo htmlspecialchars($shipment['number_of_packages']); ?></p>
                    </div>
                    <div class="summary-item">
                        <h3>Estimated Delivery</h3>
                        <p><?php echo htmlspecialchars($shipment['arrival_datetime']); ?></p>
                    </div>
                </div>
                <div class="action-buttons">
                    <button class="ups-btn primary">Track Another Package</button>
                    <button class="ups-btn secondary">Change Delivery</button>
                </div>
            </div>
        </div>
        
        <?php endif; ?>

        <aside class="sidebar">
            <div class="sidebar-card sidebar-links">
                <a href="#">Track by Reference Number</a>
                <a href="#">Import Tracking Numbers</a>
                <a href="#">Other Tracking Services</a>
            </div>

            <div class="sidebar-card">
                <h3>Stay Safe - Avoid Fraud and Scams</h3>
                <p>Received a text, call, or email that seems suspicious? Don't respond to it.</p>
                <a href="#" style="color: #0066cc; text-decoration: none;">Tips to Avoid Fraud</a>
            </div>
        </aside>
    </main>

    <footer>
        <div class="footer-content">
            <div class="footer-column">
                <h3>This Site</h3>
                <div class="footer-links">
                    <a href="#">Tracking</a>
                    <a href="#">Shipping</a>
                    <a href="#">Support</a>
                    <a href="#">Recognize a UPS Employee</a>
                </div>
            </div>
            <div class="footer-column">
                <h3>UPS Sites</h3>
                <div class="footer-links">
                    <a href="#">About UPS</a>
                    <a href="#">UPS Jobs</a>
                    <a href="#">UPS Healthcare</a>
                    <a href="#">The UPS Store</a>
                </div>
            </div>
            <div class="footer-column">
                <h3>UPS Companies</h3>
                <div class="footer-links">
                    <a href="#">Happy Returns</a>
                    <a href="#">Roadie</a>
                    <a href="#">Ware2Go Fulfillment</a>
                    <a href="#">Delivery Solutions</a>
                </div>
            </div>
            <div class="footer-column">
                <h3>Connect with Us</h3>
                <div class="footer-links">
                    <a href="#">Facebook</a>
                    <a href="#">X</a>
                    <a href="#">Instagram</a>
                    <a href="#">LinkedIn</a>
                </div>
            </div>
        </div>
        <div class="footer-bottom">
            <p>Copyright ©1994- 2025 United Parcel Service of America, Inc. All rights reserved.</p>
        </div>
    </footer>
</body>
</html>
